# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class ListStreamColumnWidth(ModelSimple):
    """
    Widget column width.

    :param value: Must be one of ["auto", "compact", "full"].
    :type value: str
    """

    allowed_values = {
        "auto",
        "compact",
        "full",
    }
    AUTO: ClassVar["ListStreamColumnWidth"]
    COMPACT: ClassVar["ListStreamColumnWidth"]
    FULL: ClassVar["ListStreamColumnWidth"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


ListStreamColumnWidth.AUTO = ListStreamColumnWidth("auto")
ListStreamColumnWidth.COMPACT = ListStreamColumnWidth("compact")
ListStreamColumnWidth.FULL = ListStreamColumnWidth("full")
