{% include "api_info.j2" %}
from __future__ import annotations

from typing import Any, Dict, List, Union, TYPE_CHECKING

from {{ package }}.model_utils import (
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    date,
    datetime,
    file_type,
    none_type,
    unset,
    UnsetType,
)

{% if "enum" in model -%}
{% include "model_enum.j2" %}
{%- elif "oneOf" in model -%}
{% include "model_oneof.j2" %}
{%- elif "array" == model.get("type") -%}
{% include "model_simple.j2" %}
{%- else -%}
{% include "model_generic.j2" %}
{%- endif %}
{# keep new line #}
