# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class ScatterplotDimension(ModelSimple):
    """
    Dimension of the Scatterplot.

    :param value: Must be one of ["x", "y", "radius", "color"].
    :type value: str
    """

    allowed_values = {
        "x",
        "y",
        "radius",
        "color",
    }
    X: ClassVar["ScatterplotDimension"]
    Y: ClassVar["ScatterplotDimension"]
    RADIUS: ClassVar["ScatterplotDimension"]
    COLOR: ClassVar["ScatterplotDimension"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


ScatterplotDimension.X = ScatterplotDimension("x")
ScatterplotDimension.Y = ScatterplotDimension("y")
ScatterplotDimension.RADIUS = ScatterplotDimension("radius")
ScatterplotDimension.COLOR = ScatterplotDimension("color")
