# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)


class EventsQueryGroupBys(ModelSimple):
    """
    The list of facets on which to split results.


    :type value: [EventsGroupBy]
    """

    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.events_group_by import EventsGroupBy

        return {
            "value": ([EventsGroupBy],),
        }
