# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class SyntheticsBasicAuthOauthTokenApiAuthentication(ModelSimple):
    """
    Type of token to use when performing the authentication.

    :param value: Must be one of ["header", "body"].
    :type value: str
    """

    allowed_values = {
        "header",
        "body",
    }
    HEADER: ClassVar["SyntheticsBasicAuthOauthTokenApiAuthentication"]
    BODY: ClassVar["SyntheticsBasicAuthOauthTokenApiAuthentication"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


SyntheticsBasicAuthOauthTokenApiAuthentication.HEADER = SyntheticsBasicAuthOauthTokenApiAuthentication("header")
SyntheticsBasicAuthOauthTokenApiAuthentication.BODY = SyntheticsBasicAuthOauthTokenApiAuthentication("body")
